{% extends "admin/base_site.html" %}
{% load i18n admin_urls static admin_modify %}

{% block breadcrumbs %}
<div class="breadcrumbs">
<a href="{% url 'admin:index' %}">{% translate 'Home' %}</a>
&rsaquo; <a href="{% url 'admin:app_list' app_label=opts.app_label %}">{{ opts.app_config.verbose_name }}</a>
&rsaquo; {% if has_view_permission %}<a href="{% url opts|admin_urlname:'changelist' %}">{{ opts.verbose_name_plural|capfirst }}</a>{% else %}{{ opts.verbose_name_plural|capfirst }}{% endif %}
&rsaquo; {% blocktranslate with name=opts.verbose_name %}Upload {{ name }}{% endblocktranslate %}
</div>
{% endblock %}

{% block content %}
<div id="content-main">
  <form action="" method="post" enctype="multipart/form-data">
    {% csrf_token %}
    {{ form }}
    {% block submit_buttons_bottom %}
      <div iclass="submit-row">
        <input type="submit" value="{% translate 'Upload' %}" class="default" name="upload">
      </div>
    {% endblock %}
  </form>
</div>
{% endblock %}
