{% extends "admin/change_list.html" %}
{% load i18n admin_urls static admin_list %}

{% block object-tools-items %}
  {{ block.super }}
  {% if has_add_permission %}                                                                            
  <li>
    {% url 'admin:flumes_django_file_upload' as upload_url %}
    <a href="{% add_preserved_filters upload_url is_popup to_field %}" class="addlink">                     
      {% blocktranslate with cl.opts.verbose_name as name %}Upload {{ name }}{% endblocktranslate %}        
    </a>
  </li>
  {% endif %}
{% endblock %}
