{% load topology %}
<div class="topology">
  <ul>
    {% for child in children %}
    <li><a href="{% url 'admin:flumes_django_stream_change' child.id %}">{{ child.type }} : {{ child.media_type }}</a></li>
      {% if child.children.count > 0 %}
      {% children_tag child %}
      {% endif %}
    {% endfor %}
  </ul>
</div>
